@@ -1,9 +1,9 @@
 <?php
 
 // -----------------------------------------------------------------------
-// This file is part of aroundme
+// This file is part of AROUNDMe
 //
-// Copyright (C) 2003, 2005 Barnraiser
+// Copyright (C) 2003 - 2006 Barnraiser
 // http://www.barnraiser.org/
 // info@barnraiser.org
 //
@@ -19,8 +19,8 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with program; see the file COPYING. If not, write to the Free
-// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA.
+// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+// 02110-1301, USA.
 // -----------------------------------------------------------------------
 
 
@@ -29,7 +29,6 @@ class Library {
 	// CLASS FUNCTIONS
 	// Library
 	// selLibraryItems
-	// selRspLibraryItems
 	// getPages
 	// getPageName
 	// getPageID
@@ -45,11 +44,10 @@ class Library {
 	// the constuctor
 	// tom calthrop - 18th May 2004
 	//
-	function Library($db, $rsp_item_type_id, $date, $file = null) {
+	function Library($db, $rsp_item_type_id, $file=null) {
 		$this->db = $db;
 		$this->rsp_item_type_id = $rsp_item_type_id;
-		$this->date = $date;
-
+		
 		if (isset($file)) {
 		    $this->file = $file;
 		}
@@ -69,15 +67,12 @@ class Library {
 			WHERE "
 		;
 		
-		if (isset($this->group_id) && $this->group_id == 0) {
-		    $query .= "l.group_id is null AND ";
-		}
-		elseif (isset($this->group_id)) {
-		    $query .= "l.group_id=" . $this->group_id . " AND ";
+		if (isset($this->user_id)) {
+			$query .= "l.user_id=" . $this->user_id . " AND ";
 		}
 		
-		if (isset($this->user_id)) { // group list
-			$query .= "l.user_id=" . $this->user_id . " AND ";
+		if (isset($this->group_id)) {
+			$query .= "l.group_id=" . $this->group_id . " AND ";
 		}
 		
 		$query .="1=1 order by l.library_page_name";
@@ -109,26 +104,79 @@ class Library {
 	// get the library items for given ids
 	// tom calthrop - 10th December 2004
 	//
-	function selLibraryItems() {
-
-	    $query = "
-			SELECT l.library_id, l.library_page_name, l.library_title, l.library_synopsis,
-			l.file_id, l.group_id, l.library_allow_comments, l.library_create_datetime, l.user_id 
-			FROM " . $this->db->prefix . "_library l
-			WHERE "
+	function selLibraryItems($search = null) {
+		$query = "
+			SELECT DISTINCT l.library_id, l.library_page_name, l.library_title, l.library_synopsis,
+			l.file_id, l.library_allow_comments, l.library_create_datetime, l.user_id, l.group_id "
 		;
 		
-		if (isset($this->group_id) && $this->group_id == 0) {
-		    $query .= "l.group_id is null AND ";
+		if (isset($this->rsp_item_type_id)) {
+			$query .= ", pr.profile_create_datetime, pr.profile_nic, pr.profile_hometown, rsp.rsp_sticky ";
 		}
-		elseif (isset($this->group_id)) {
-		    $query .= "l.group_id=" . $this->group_id . " AND ";
+			
+		$query .= "FROM " . $this->db->prefix . "_library l ";
+		
+		if (isset($this->tag)) {
+			$query .= ", " . $this->db->prefix . "_tag t  ";
+		}
+		
+		if (isset($this->rsp_item_type_id)) {
+			$query .= ", " . $this->db->prefix . "_rsp rsp 
+			LEFT JOIN " . $this->db->prefix . "_user_profile pr ON l.user_id=pr.user_id AND pr.profile_default=1 ";
+		}
+		
+		$query .= "WHERE ";
+		
+		if (isset($this->tag)) {
+			$query .= "
+				l.library_id=t.item_id AND 
+				t.user_id=" . $this->me['user_id'] . " AND 
+				t.rsp_item_type_id=" . $this->item_types['library'] . " AND
+				t.tag_body like " . $this->db->qstr("%" . $this->tag . "%", get_magic_quotes_gpc()) . " AND "
+			;
+		}
+		
+		if (isset($this->rsp_item_type_id)) {
+			$query .= "
+				rsp.item_id=l.library_id AND
+				rsp.level_id=" . $this->rsp_level_id . " AND 
+				rsp.rsp_item_type_id=" . $this->rsp_item_type_id . " AND "
+			;
+			
+			if (isset($this->rsp_status_id)) {
+				$query .= "rsp.status_id=" . $this->rsp_status_id . " AND ";
+			}
+		}
+		
+		if (isset($search)) {
+			$query .= "
+				(
+				l.library_title like " . $this->db->qstr("%" . $search . "%", get_magic_quotes_gpc()) . " OR 
+				l.library_synopsis like " . $this->db->qstr("%" . $search . "%", get_magic_quotes_gpc()) . " OR 
+				l.library_body like " . $this->db->qstr("%" . $search . "%", get_magic_quotes_gpc()) . "
+				) and "
+			;
 		}
 		
 		if (isset($this->user_id)) { // group list
 			$query .= "l.user_id=" . $this->user_id . " AND ";
 		}
 		
+		if (isset($this->group_id)) {
+			$query .= "l.group_id=" . $this->group_id . " AND ";
+		}
+		
+		if (isset($this->user_ids)) {
+			$user_ids = "";
+			foreach($this->user_ids as $key => $i):
+				$user_ids .= $i;
+				if (count($this->user_ids) > $key+1) {
+					$user_ids .=",";
+				}
+			endforeach;
+			$query .="l.user_id in (" . $user_ids . ") and ";
+		}
+		
 		if (isset($this->library_ids)) { //used for bookmarks
 			$library_ids = "";
 			foreach($this->library_ids as $key => $i):
@@ -139,15 +187,22 @@ class Library {
 			endforeach;
 			$query .= "l.library_id in (" . $library_ids . ") AND ";
 		}
-
-		$query .= "1=1 order by l.library_page_name";
+		
+		$query .="1=1 ";
+		
+		if (isset($this->order_by)) {
+		    $query .= "order by l." . $this->order_by;
+		}
+		else {
+			$query .= "order by l.library_page_name";
+		}
 		
 		if (isset($this->limit)) {
 			$result = $this->db->SelectLimit($query, $this->limit);
 		} else {
 			$result = $this->db->Execute($query);
 		}
-
+		//echo $query;
 		if (isset($result->fields)) {
 			$temp = array();
 
@@ -155,13 +210,6 @@ class Library {
 				$temp1 = $result->fields;
 
 				if (isset($this->file)) {
-					if ($temp1['group_id'] > 0) {
-						$this->file->path = $this->file->config_ids['image']['path']['group'];
-					}
-					else {
-					    $this->file->path = $this->file->config_ids['image']['path']['user'];
-					}
-
 					if (isset($temp1['file_id'])) {
 						$this->file->file_id = $temp1['file_id'];
 						$temp1['image'] = $this->file->getFileRecord();
@@ -171,9 +219,13 @@ class Library {
 						$temp1['image']['file'] = $this->file->noimage;
 					}
 				}
-
-				$temp1['library_create_datetime'] = $this->date->formatDate($temp1['library_create_datetime'], 1);
-
+				
+				//format search results
+				if (isset($search)) {
+					$temp1['library_synopsis'] = searchTextFormat($search, $temp1['library_synopsis']);
+					$temp1['library_title'] = searchTextFormat($search, $temp1['library_title']);
+				}
+				
 				array_push($temp, $temp1);
 				$result->MoveNext();
 			}
@@ -189,114 +241,6 @@ class Library {
 
 
 
-	// selRspLibraryItems --------------------------------------------------------------------
-	// get the library items for given ids
-	// tom calthrop - 10th December 2004
-	//
-	function selRspLibraryItems($search = null) {
-	    $query = "
-			SELECT l.library_id, l.library_page_name, l.library_title, l.library_synopsis,
-			l.file_id, l.group_id, l.library_allow_comments, l.library_create_datetime,
-			l.group_id, rsp.rsp_sticky
-			FROM " . $this->db->prefix . "_library l, " .$this->db->prefix . "_rsp rsp
-			WHERE
-			rsp.item_id=l.library_id AND
-			rsp.level_id=" . $this->rsp_level_id . " AND
-			rsp.status_id=" . $this->rsp_status_id . " AND
-			rsp.rsp_item_type_id=" . $this->rsp_item_type_id . " AND "
-		;
-
-		if (isset($this->degree_id)) {
-		    $query .= "rsp.degree_id>=" . $this->degree_id . " AND ";
-		}
-
-		if (isset($this->group_id) && $this->group_id == 0) {
-		    $query .= "l.group_id is null AND ";
-		}
-		elseif (isset($this->group_id)) {
-		    $query .= "l.group_id=" . $this->group_id . " AND ";
-		}
-		
-		if (isset($this->user_id)) { // group list
-			$query .= "l.user_id=" . $this->user_id . " AND ";
-		}
-
-		if (isset($search)) {
-			$query .= "
-				(
-				l.library_title like '%" . $search . "%' or
-				l.library_synopsis like '%" . $search . "%' or
-				l.library_body like '%" . $search . "%'
-				) and "
-			;
-		}
-
-		if (isset($this->user_ids)) {
-			$user_ids = "";
-			foreach($this->user_ids as $key => $i):
-				$user_ids .= $i;
-				if (count($this->user_ids) > $key+1) {
-					$user_ids .=",";
-				}
-			endforeach;
-			$query .="l.user_id in (" . $user_ids . ") and ";
-		}
-
-		$query .= "1=1 order by l.library_page_name";
-
-		if (isset($this->limit)) {
-			$result = $this->db->SelectLimit($query, $this->limit);
-		} else {
-			$result = $this->db->Execute($query);
-		}
-
-		if (isset($result->fields)) {
-			$temp = array();
-
-			while (!$result->EOF) {
-				$temp1 = $result->fields;
-
-				if (isset($this->file)) {
-					if ($temp1['group_id'] > 0) {
-						$this->file->path = $this->file->config_ids['image']['path']['group'];
-					}
-					else {
-					    $this->file->path = $this->file->config_ids['image']['path']['user'];
-					}
-
-					if (isset($temp1['file_id'])) {
-						$this->file->file_id = $temp1['file_id'];
-						$temp1['image'] = $this->file->getFileRecord();
-					}
-					else {
-						$temp1['image']['file_title'] = "";
-						$temp1['image']['file'] = $this->file->noimage;
-					}
-				}
-
-				$temp1['library_create_datetime'] = $this->date->formatDate($temp1['library_create_datetime'], 1);
-
-				//format search results
-				if (isset($search)) {
-					$temp1['library_synopsis'] = searchTextFormat($search, $temp1['library_synopsis']);
-					$temp1['library_title'] = searchTextFormat($search, $temp1['library_title']);
-				}
-
-				array_push($temp, $temp1);
-				$result->MoveNext();
-			}
-
-			$result->Close();
-			return $temp;
-		}
-		else {
-			$error_info = "function=selRspLibraryItems class=Library.class.php -- " . $query . " -- " . $this->db->ErrorMsg();
-			$GLOBALS['am_error_log'][] = array(1, 1, $error_info);
-		}
-	}//EO selRspLibraryItems
-
-
-
 	// getPageName --------------------------------------------------------------------
 	// will get the newest page for $library_page_name
 	// tom calthrop - 18th May 2004
@@ -306,28 +250,27 @@ class Library {
 			SELECT *
 			FROM " . $this->db->prefix . "_library l 
 			WHERE 
-			l.library_page_name='" . $library_page_name . "' AND "
+			l.library_page_name=" . $this->db->qstr($library_page_name, get_magic_quotes_gpc()) . " AND "
 		;
 		
-		if (isset($this->group_id) && $this->group_id == 0) {
-		    $query .= "l.group_id is null AND ";
-		}
-		elseif (isset($this->group_id)) {
-		    $query .= "l.group_id=" . $this->group_id . " AND ";
-		}
-		
 		if (isset($this->user_id)) { // group list
 			$query .= "l.user_id=" . $this->user_id . " AND ";
 		}
 		
+		if (isset($this->group_id)) {
+			$query .= "l.group_id=" . $this->group_id . " AND ";
+		}
+		
 		$query .= "1=1 order by l.library_create_datetime desc";
 
 		$result = $this->db->SelectLimit($query, 1);
 
 		if (isset($result->fields)) {
-			$temp = $result->fields;
-			$this->library_id = $temp['library_id'];
-			return $temp;
+			if (!empty($result->fields)) {
+				$temp = $result->fields;
+				$this->library_id = $temp['library_id'];
+				return $temp;
+			}
 		}
 		else {
 			$error_info = "function=getPageName class=Library.class.php -- " . $query . " -- " . $this->db->ErrorMsg();
@@ -377,32 +320,34 @@ class Library {
 	function getPageDefault() {
 		$query = "
 			SELECT l.library_id, l.library_page_name, l.library_title, l.library_synopsis,
-			l.file_id, l.group_id, l.library_allow_comments, l.library_create_datetime,
-			l.group_id, l.library_body, l.user_id  
+			l.file_id, l.library_allow_comments, l.library_create_datetime,
+			l.library_body, l.user_id, l.group_id  
 			FROM " . $this->db->prefix . "_library l 
 			WHERE 
 			l.library_default is not null AND "
 		;
 		
-		if (isset($this->group_id) && $this->group_id == 0) {
-		    $query .= "l.group_id is null AND ";
-		}
-		elseif (isset($this->group_id)) {
-		    $query .= "l.group_id=" . $this->group_id . " AND ";
-		}
-		
 		if (isset($this->user_id)) { // group list
 			$query .= "l.user_id=" . $this->user_id . " AND ";
 		}
 		
-		$query .= "1=1 order by l.library_create_datetime";
-
+		if (isset($this->group_id)) {
+			$query .= "l.group_id=" . $this->group_id . " AND ";
+		}
+		else {
+			$query .= "l.group_id is null AND ";
+		}
+		
+		$query .= "1=1 order by l.library_create_datetime desc";
+		
 		$result = $this->db->SelectLimit($query, 1); //returns last 1 rows
 
 		if (isset($result->fields)) {
-			$temp = $result->fields;
-			$this->library_id = $temp['library_id'];
-			return $temp;
+			if (!empty($result->fields)) {
+				$temp = $result->fields;
+				$this->library_id = $temp['library_id'];
+				return $temp;
+			}
 		}
 		else {
 			$error_info = "function=getPageDefault class=Library.class.php -- " . $query . " -- " . $this->db->ErrorMsg();
@@ -426,27 +371,24 @@ class Library {
 		if (!empty($pagename)) {
 			$query = "
 				SELECT l.library_id, l.library_title, l.library_create_datetime, l.user_id,
-				p.profile_nic
+				p.profile_nic, l.group_id 
 				FROM " . $this->db->prefix . "_library l
 				LEFT JOIN " . $this->db->prefix . "_user_profile p ON l.user_id=p.user_id
 				WHERE
 				p.profile_default=1 AND 
-				l.library_page_name='" . $pagename . "' AND "
+				l.library_page_name=" . $this->db->qstr($pagename, get_magic_quotes_gpc()) . " AND "
 			;
 			
-			if (isset($this->group_id) && $this->group_id == 0) {
-				$query .= "l.group_id is null AND ";
-			}
-			elseif (isset($this->group_id)) {
-				$query .= "l.group_id=" . $this->group_id . " AND ";
-			}
-			
 			if (isset($this->user_id)) { // group list
 				$query .= "l.user_id=" . $this->user_id . " AND ";
 			}
-		
+			
+			if (isset($this->group_id)) {
+				$query .= "l.group_id=" . $this->group_id . " AND ";
+			}
+			
 			$query .= "1=1 order by l.library_create_datetime desc";
-
+			
 			$result = $this->db->Execute($query);
 
 			if (isset($result->fields)) {
@@ -454,7 +396,6 @@ class Library {
 
 				while (!$result->EOF) {
 					$temp1 = $result->fields;
-					$temp1['display_library_create_datetime'] = $this->date->formatDate($temp1['library_create_datetime'], 1);
 					array_push($temp, $temp1);
 					$result->MoveNext();
 				}
@@ -483,17 +424,14 @@ class Library {
 			WHERE "
 		;
 		
-		if (isset($this->group_id) && $this->group_id == 0) {
-		    $query .= "l.group_id is null AND ";
-		}
-		elseif (isset($this->group_id)) {
-		    $query .= "l.group_id=" . $this->group_id . " AND ";
-		}
-		
-		if (isset($this->user_id)) { // group list
+		if (isset($this->user_id)) {
 			$query .= "l.user_id=" . $this->user_id . " AND ";
 		}
-			
+		
+		if (isset($this->group_id)) {
+			$query .= "l.group_id=" . $this->group_id . " AND ";
+		}
+		
 		$query .= "1=1 order by l.library_page_name, l.library_create_datetime desc";
 		
 		$result = $this->db->Execute($query);
@@ -518,21 +456,14 @@ class Library {
 				$query = "
 					SELECT l.library_id, l.library_title, l.library_create_datetime, l.user_id,
 					p.profile_nic, l.library_default, l.library_synopsis,
-					l.library_default
+					l.library_default, l.group_id 
 					FROM " . $this->db->prefix . "_library l
 					LEFT JOIN " . $this->db->prefix . "_user_profile p ON l.user_id=p.user_id
 					WHERE
 					p.profile_default=1 AND "
 				;
 				
-				if (isset($this->group_id) && $this->group_id == 0) {
-					$query .= "l.group_id is null AND ";
-				}
-				elseif (isset($this->group_id)) {
-					$query .= "l.group_id=" . $this->group_id . " AND ";
-				}
-				
-				if (isset($this->user_id)) { // group list
+				if (isset($this->user_id)) {
 					$query .= "l.user_id=" . $this->user_id . " AND ";
 				}
 
@@ -548,8 +479,7 @@ class Library {
 
 					while (!$result->EOF) {
 						$temp1 = $result->fields;
-						$temp1['library_create_datetime'] = $this->date->formatDate($temp1['library_create_datetime'], 1);
-
+						
 						array_push($temp, $temp1);
 						$result->MoveNext();
 					}
@@ -582,47 +512,45 @@ class Library {
 		if(empty($data['library_title'])) {
 			$GLOBALS['am_error_log'][] = array(11, null, null);
 		}
-
+		
 		if(empty($data['library_body'])) {
 			$GLOBALS['am_error_log'][] = array(12, null, null);
 		}
-
+		
 		if(empty($data['library_synopsis'])) {
 			$GLOBALS['am_error_log'][] = array(13, null, null);
 		}
-
+		
 		if (empty($GLOBALS['am_error_log'])) {
-
-			$datetime = date("Y-m-d H:i:s");
-			$datetime = $this->db->DBDate($datetime);
-
-			if (!isset($data['file_id']) || $data['file_id'] < 1) {
+			
+			if (empty($data['file_id'])) {
 			    $data['file_id'] = "null";
 			}
-
-			if (empty($data['library_allow_comments'])) {
-			    $data['library_allow_comments'] = "null";
+			
+			if (empty($data['group_id'])) {
+			    $data['group_id'] = "null";
 			}
 			
-			if (isset($this->group_id) && $this->group_id > 0) {
-			    $group_id = $this->group_id;
-			}
-			else {
-				$group_id = "null";
+			if (empty($data['library_allow_comments'])) {
+			    $data['library_allow_comments'] = "null";
 			}
 
 			if (isset($data['library_default']) && $data['library_default'] > 0) {
 			    //we clear out all old default pages
 				$query = "
-					UPDATE " . $this->db->prefix . "_library SET
-					library_default = null
-					WHERE
-					group_id=" . $group_id . " AND
+					SELECT * FROM " . $this->db->prefix . "_library
+					WHERE 
 					user_id=" . $this->user_id
 				;
-
+				
 				$result = $this->db->Execute($query);
-
+				
+				$rec = array();
+				$rec['library_default'] = "null";
+				
+				$query = $this->db->GetUpdateSQL($result, $rec, false, get_magic_quotes_gpc());
+				$result = $this->db->Execute($query);
+				
 			}
 			else {
 				$data['library_default'] = "null";
@@ -631,65 +559,29 @@ class Library {
 			if (!empty($data['page'])) {
 			    $data['library_page_name'] = $data['page'];
 			}
-
-			$query = "
-				INSERT INTO " . $this->db->prefix . "_library (
-				group_id,
-				library_title,
-				library_synopsis,
-				library_body,
-				language_id,
-				file_id,
-				library_page_name,
-				user_id,
-				library_create_datetime,
-				library_allow_comments,
-				library_default
-				) VALUES (
-				'" . $group_id . "',
-				'" . $data['library_title'] . "',
-				'" . $data['library_synopsis'] . "',
-				'" . $data['library_body'] . "',
-				'" . $data['language_id'] . "',
-				" . $data['file_id'] . ",
-				'" . $data['library_page_name'] . "',
-				" . $this->user_id . ",
-				" . $datetime . ",
-				" . $data['library_allow_comments'] . ",
-				" . $data['library_default'] . "
-				)"
-			;
-
+			
+			$rec = array();
+			$rec['library_title'] = $data['library_title'];
+			$rec['library_synopsis'] = $data['library_synopsis'];
+			$rec['library_body'] = $data['library_body'];
+			$rec['language_id'] = $data['language_id'];
+			$rec['file_id'] = $data['file_id'];
+			$rec['library_page_name'] = $data['library_page_name'];
+			$rec['user_id'] = $this->user_id;
+			$rec['group_id'] = $data['group_id'];
+			$rec['library_create_datetime'] = time();
+			$rec['library_allow_comments'] = $data['library_allow_comments'];
+			$rec['library_default'] = $data['library_default'];
+			
+			$table = $this->db->prefix . "_library";
+			
+			$query = $this->db->GetInsertSQL($table, $rec, get_magic_quotes_gpc());
 			$result = $this->db->Execute($query);
-
+			
 			if (isset($result->fields)) {
-				$query = "
-					SELECT l.library_id, l.library_page_name 
-					FROM " . $this->db->prefix . "_library l 
-					WHERE 
-					l.library_create_datetime=" . $datetime . " AND "
-				;
 				
-				if (isset($this->group_id)) {
-				    $query .= "l.group_id=" . $this->group_id . " AND ";
-				}
-				
-				if (isset($this->user_id)) { // group list
-					$query .= "l.user_id=" . $this->user_id . " AND ";
-				}
-				
-				$query .= "1=1";
-				
-				$result = $this->db->SelectLimit($query, 1);
-
-				if (isset($result->fields['library_id'])) {
-					$this->library_id = $result->fields['library_id'];
-					$this->library_page_name = $result->fields['library_page_name'];
-				}
-				else {
-					$error_info = "function=insertLibrary class=Library.class.php -- " . $query . " -- " . $this->db->ErrorMsg();
-					$GLOBALS['am_error_log'][] = array(1, 1, $error_info);
-				}
+				$this->library_id = $this->db->Insert_ID();
+				$this->library_page_name = $data['library_page_name'];
 			}
 			else {
 				$error_info = "function=insertLibrary class=Library.class.php -- " . $query . " -- " . $this->db->ErrorMsg();
@@ -702,7 +594,7 @@ class Library {
 
 
 	// getLibraryItemCount --------------------------------------------------------------------
-	// will get the coutn of unique page names
+	// will get the count of unique page names
 	// tom calthrop - 27th December 2004
 	//
 	function getLibraryItemCount($user_id = null) {
@@ -712,23 +604,25 @@ class Library {
 			WHERE "
 		;
 		
-		if (isset($this->group_id) && $this->group_id == 0) {
-		    $query .= "l.group_id is null AND ";
-		}
-		elseif (isset($this->group_id)) {
-		    $query .= "l.group_id=" . $this->group_id . " AND ";
+		if (isset($user_id)) {
+			$query .= "l.user_id=" . $user_id . " AND ";
 		}
 		
-		if (isset($user_id)) { // group list
-			$query .= "l.user_id=" . $user_id . " AND ";
+		if (isset($this->group_id)) {
+			$query .= "l.group_id=" . $this->group_id . " AND ";
 		}
 		
 		$query .= "1=1";
 		
 		$result = $this->db->Execute($query);
-
-		if (isset($result->fields['library_page_name'])) {
-			return count($result->fields);
+		
+		if (isset($result)) {
+			if (isset($result->fields['library_page_name'])) {
+				return count($result->fields);
+			}
+			else {
+				return 0;
+			}
 		}
 		else {
 			$error_info = "function=getLibraryItemCount class=Library.class.php -- " . $query . " -- " . $this->db->ErrorMsg();
