@@ -1,9 +1,9 @@
 <?php
 
 // -----------------------------------------------------------------------
-// This file is part of aroundme
+// This file is part of AROUNDMe
 //
-// Copyright (C) 2003, 2005 Barnraiser
+// Copyright (C) 2003 - 2006 Barnraiser
 // http://www.barnraiser.org/
 // info@barnraiser.org
 //
@@ -19,8 +19,8 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with program; see the file COPYING. If not, write to the Free
-// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA.
+// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+// 02110-1301, USA.
 // -----------------------------------------------------------------------
 
 ?>
@@ -28,42 +28,28 @@
 <script language="JavaScript" src="js/imageHandling.js" type="text/javascript"></script>
 
 <form action="lib_edit.php" method="post" name="frm" id="id_frm">
-<input type="hidden" name="group_id" value="<?php if(isset($group['group_id'])) { echo $group['group_id'];} elseif (isset($library['group_id'])) { echo $library['group_id'];}?>" />
-<input type="hidden" name="page" value="<?php if(isset($library['library_page_name'])) { echo $library['library_page_name'];}?>" />
+<input type="hidden" name="group_id" value="<?php if(isset($group['group_id'])) { echo $group['group_id'];} elseif (isset($blog['group_id'])) { echo $blog['group_id'];}?>" />
 
-<table width="100%" border="0" cellspacing="0" cellpadding="0">
-	<tr>
-		<td width="760" valign="top">
-			<div class="box_top">
-				<?php echo $lang['section_library'];?><br />
-			</div>
-
-			<div class="box_mid" style="padding: 9px;">
-
-			<?php
-			if (isset($display) && $display == "allow_edit") {
-			?>
+<div class="box">
+	<div class="box_top">
+		<?php echo $lang['hdr_library'];?><br />
+	</div>
+	
+	<div class="box_mid">
+		<div class="content">
 			<table border="0" cellspacing="0" cellpadding="0" width="100%">
 				<tr>
-					<td>
+					<td colspan="3">
 						<b>
 						<?php
 						if (isset($group)) {
-							echo $lang['hdr_group_library'];
+							echo $lang['hdr_group_library'] . ": " . $group['group_title'];
 						}
 						else {
 							echo $lang['hdr_library'];
 						}
 						?></b><br />
 						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="12" alt="" /><br />
-
-					</td>
-					<td valign="top" colspan="2" align="right">
-						<?php
-						if (isset($info_pages)) {
-						?>
-						<span class="button_info" onclick="launchPopupWindow('man.php?paragraph_ids=<?php echo $info_pages;?>', 'quick help', 'height=300,width=450,menubar=no,scrollbars=yes,status=no,location=no', '450');"><?php echo $lang['href_information'];?></span><br />
-						<?php }?>
 					</td>
 				</tr>
 				<tr>
@@ -93,22 +79,6 @@
 									<img src="<?php echo $templatePath;?>img/pixel.png" width="10" height="1" alt="" /><br />
 								</td>
 								<td valign="top">
-									<p>
-									<label for="id_genre"><?php echo $lang['form_label_genre'];?></label>
-									<select id="id_genre" name="genre_id">
-									<?php
-									foreach($lang['arr_genre'] as $key => $i):
-									$selected = "";
-
-									if (isset($library['library_genre_id']) && $library['library_genre_id'] == $key) {
-									    $selected = " selected=\"selected\"";
-									}
-									?>
-									<option value="<?php echo $key;?>"<?php echo $selected;?>><?php echo $i;?></option>
-									<?php endforeach; ?>
-									</select>
-									</p>
-
 									<?php
 									if (count($me['language_ids']) > 1) {
 									?>
@@ -121,14 +91,44 @@
 									</select>
 									</p>
 									<?php }?>
+								</td>
+							</tr>
+							<tr>
+								<td colspan="3">
+									<?php
+									if (!empty($library['library_page_name'])) {
+									?>
+									<input type="hidden" name="page" value="<?php echo $library['library_page_name'];?>" />
+									<?php echo $lang['form_label_wiki_page'] . ": " . $library['library_page_name'];?><br />
+									
+									<?php
+									}
+									else {
+									?>
+									<p>
+									<?php echo $lang['txt_wiki_intro'];?><br />
+									</p>
+									<p>
+									<label for="id_wiki_page"><?php echo $lang['form_label_wiki_page'];?></label>
+									<input id="id_wiki_page" type="text" name="wiki_page" size="30" value="<?php if (!empty($library['library_page_name'])) { echo $library['library_page_name'];} elseif (isset($library['wiki_page'])) { echo $library['wiki_page'];}?>" /><br />
+									</p>
+									<?php }?>
 
 									<?php
+									if (isset($group) && $this->group_acs->checkPermission($resource_ids['group']['library'], $privilege_ids['allow_lib_default'])) { //resourece_id, Priv_id
+										$allow_default_display = 1;
+									}
+									elseif (!isset($group) && $this->user_acs->checkPermission($resource_ids['node']['library'], $privilege_ids['allow_lib_default'])) { //resourece_id, Priv_id
+										$allow_default_display = 1;
+									
+									}
+									
 									if (isset($library['library_default']) && $library['library_default'] > 0) {
 									?>
 									<input type="hidden" name="library_default" value="1" />
 									<?php
 									}
-									else {
+									elseif (isset($allow_default_display)) {
 									?>
 									<p>
 									<label for="id_default"><?php echo $lang['txt_default'];?></label>
@@ -169,13 +169,13 @@
 							</tr>
 							<tr>
 								<td align="right">
-									<input type="submit" name="preview" value="<?php echo $lang['form_submit_preview'];?>" class="button_light" />
+									<input type="submit" name="preview" value="<?php echo $lang['sub_preview'];?>" class="button_light" />
 									
 									<?php
 									if (isset($allow_spellcheck)) {
 									?>
 									&nbsp;&nbsp;
-									<input type="button" value="<?php echo $lang['txt_check_spelling'];?>" onClick="openSpellChecker();" class="button_light" />
+									<input type="button" value="<?php echo $lang['sub_check_spelling'];?>" onClick="openSpellChecker();" class="button_light" />
 									<?php }?>
 									<br />
 								</td>
@@ -281,12 +281,12 @@
 								}
 							endforeach;
 						}
-
-						if (isset($group)) {
 						?>
-						<table border="0" cellspacing="0" cellpadding="4" width="100%">
+
+						<table border="0" cellspacing="0" cellpadding="2" width="100%">
 							<?php
-							if ($this->group_acs->checkPermission($resource_ids['group_rsp'], $privilege_ids['allow_rsp_public'])) { //resource_id, Priv_id
+							if (isset($group)) {
+							if ($this->group_acs->checkPermission($resource_ids['group']['rsp'], $privilege_ids['allow_rsp_public'])) { //resource_id, Priv_id
 							?>
 							<tr>
 								<td valign="top">
@@ -303,7 +303,7 @@
 							<tr>
 							<?php 
 							}
-							if ($this->group_acs->checkPermission($resource_ids['group_rsp'], $privilege_ids['allow_rsp_node'])) { //resource_id, Priv_id
+							if ($this->group_acs->checkPermission($resource_ids['group']['rsp'], $privilege_ids['allow_rsp_node'])) { //resource_id, Priv_id
 								if ($rspconfig['node']['auto_publish'] == 1) {
 									$txt_rsp_node = $lang['form_rsp_node_auto'];
 								}
@@ -326,7 +326,8 @@
 							<tr>
 							<?php
 							}
-							if ($this->group_acs->checkPermission($resource_ids['group_rsp'], $privilege_ids['allow_rsp_group_home'])) { //resource_id, Priv_id
+
+							if ($this->group_acs->checkPermission($resource_ids['group']['rsp'], $privilege_ids['allow_rsp_group_home'])) { //resource_id, Priv_id
 								if ($group['group_rsp_auto_publish'] == 1) {
 									$txt_rsp_group = $lang['form_rsp_group_auto'];
 								}
@@ -336,6 +337,7 @@
 							?>
 							<tr>
 								<td valign="top">
+									
 									<input id="id_allow_rsp_group" type="checkbox" name="rsp_group" class="checkbox" value="1" <?php if (isset($rsp_group_home) && $rsp_group_home == 1) { echo "checked=\"checked\"";}?> /><br />
 								</td>
 								<td valign="top">
@@ -343,65 +345,42 @@
 								</td>
 							</tr>
 							<?php } ?>
-							<tr>
-								<td colspan="2">
-									<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="3" alt="" /><br />
-								</td>
-							<tr>
-							<tr>
-								<td valign="top">
-									<input id="id_allow_comments" type="checkbox" name="library_allow_comments" class="checkbox" value="1" <?php if (isset($library['library_allow_comments']) && $library['library_allow_comments'] == 1) { echo "checked=\"checked\"";}?> /><br />
-								</td>
-								<td valign="top">
-									<label style="width:100%" for="id_allow_comments"><?php echo $lang['form_label_comments'];?></label><br />
-								</td>
-							</tr>
-						</table>
-						<?php
-						}
-						else {
-						?>
-
-						<script type="text/javascript">
-						function setDegreeEveryone(id) {
-							if (id.checked) {
-								document.getElementById('id_degree_id').checked=true;
+							<?php
 							}
-						}
-						function setPublishingOff() {
-							document.getElementById('id_level_id_node').checked=false;
-							document.getElementById('id_level_id_public').checked=false;
+							else {
+							?>
+							
+							
 							
-						}
-						</script>
-						<table border="0" cellspacing="0" cellpadding="2" width="100%">
 							<tr>
 								<td width="1">
-									<input type="radio" class="checkbox" name="rsp_degree" value="" checked="checked" /><br />
+									<input type="radio" class="checkbox" name="rsp_degree" value="" checked="checked" onClick="javascript:setPublishingOff();" /><br />
 								</td>
 								<td>
 									<?php echo $lang['form_just_me'];?><br />
 								</td>
 							</tr>
+							
+							
 							<?php
+							if ($this->user_acs->checkPermission($resource_ids['node']['rsp'], $privilege_ids['allow_rsp_network'])) { //resourece_id, Priv_id
 							$selected="";
-							foreach($lang['sn']['degree'] as $key => $i):
-
-							if (isset($rsp_degree) && $key == $rsp_degree) {
+							if (isset($rsp_degree)) {
 								$selected=" checked=\"checked\"";
 							}
 							?>
 							<tr>
 								<td width="1">
-									<input type="radio" class="checkbox" name="rsp_degree" value="<?php echo $key;?>"<?php echo $selected;?> onChange="javascript:setPublishingOff();" /><br />
+									<input type="radio" name="rsp_degree" class="checkbox" value="1"<?php echo $selected;?> onClick="javascript:setPublishingOff();" /><br />
 								</td>
 								<td>
-									<?php echo $i;?><br />
+									<?php echo $lang['txt_degree_nw'];?><br />
 								</td>
 							</tr>
+							<?php }?>
+							
 							<?php
 							$selected="";
-							endforeach;
 							if (isset($rsp_degree_set) && empty($rsp_degree)) {
 								$selected=" checked=\"checked\"";
 							}
@@ -411,12 +390,12 @@
 									<input id="id_degree_id" type="radio" class="checkbox" name="rsp_degree" value="all"<?php echo $selected;?> /><br />
 								</td>
 								<td>
-									<?php echo $lang['txt_publish_level'];?><br />
+									<?php echo $lang['txt_publish_all'];?><br />
 								</td>
 							</tr>
+							
 							<?php
-
-							if ($this->user_acs->checkPermission($resource_ids['rsp'], $privilege_ids['allow_rsp_node'])) { //resourece_id, Priv_id
+							if ($this->user_acs->checkPermission($resource_ids['node']['rsp'], $privilege_ids['allow_rsp_node'])) { //resourece_id, Priv_id
 							$selected="";
 							if (isset($rsp_node) && $rsp_node == 1) {
 								$selected=" checked=\"checked\"";
@@ -424,7 +403,7 @@
 							?>
 							<tr>
 								<td valign="top">
-									<input type="checkbox" id="id_level_id_node" name="rsp_node" value="1"<?php echo $selected;?> class="checkbox" onChange="javascript:setDegreeEveryone(this);" /><br />
+									<input type="checkbox" id="id_level_id_node" name="rsp_node" value="1"<?php echo $selected;?> class="checkbox" onClick="javascript:setDegreeEveryone(this);" /><br />
 								</td>
 								<td>
 									<?php echo $lang['txt_publish_node_help'];?><br />
@@ -433,7 +412,7 @@
 							<?php
 							}
 
-							if ($this->user_acs->checkPermission($resource_ids['rsp'], $privilege_ids['allow_rsp_public'])) { //resourece_id, Priv_id
+							if ($this->user_acs->checkPermission($resource_ids['node']['rsp'], $privilege_ids['allow_rsp_public'])) { //resourece_id, Priv_id
 							$selected="";
 							if (isset($rsp_public) && $rsp_public == 1) {
 								$selected=" checked=\"checked\"";
@@ -441,13 +420,14 @@
 							?>
 							<tr>
 								<td valign="top">
-									<input type="checkbox" id="id_level_id_public" name="rsp_public" value="1"<?php echo $selected;?> class="checkbox" onChange="javascript:setDegreeEveryone(this);" /><br />
+									<input type="checkbox" id="id_level_id_public" name="rsp_public" value="1"<?php echo $selected;?> class="checkbox" onClick="javascript:setDegreeEveryone(this);" /><br />
 								</td>
 								<td>
 									<?php echo $lang['txt_publish_public_help'];?><br />
 								</td>
 							</tr>
 							<?php }?>
+							<?php }?>
 							<tr>
 								<td colspan="2">
 									<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="3" alt="" /><br />
@@ -462,7 +442,6 @@
 								</td>
 							</tr>
 						</table>
-						<?php }?>
 						</fieldset>
 
 						<script type="text/javascript">
@@ -485,40 +464,19 @@
 
 						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="6" alt="" /><br />
 
-						<input type="submit" name="save" class="button_urgent" value="<?php echo $lang['form_submit_save'];?>" />&nbsp;
-						<input type="submit" name="save_go" class="button_urgent" value="<?php echo $lang['form_submit_save_go'];?>" /><br />
+						<input type="submit" name="save" class="button_urgent" value="<?php echo $lang['sub_save'];?>" />&nbsp;
+						<input type="submit" name="save_go" class="button_urgent" value="<?php echo $lang['sub_save_go'];?>" /><br />
 
 						</fieldset>
 					</td>
 				</tr>
 			</table>
-
-			<?php
-			}
-			else { //no edit allowed
-			?>
-
-			<?php echo $lang['err_library_item_edit'];?><br />
-
-			<?php }?>
-			</div>
-
-			<div id="box_bottom">
-				<table cellpadding="0" cellspacing="0" border="0" width="100%">
-					<tr>
-						<td align="left">
-							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
-						</td>
-						<td align="left">
-							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
-						</td>
-						<td align="right">
-							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
-						</td>
-					</tr>
-				</table>
-			</div>
-		</td>
-	</tr>
-</table>
+		</div>
+	</div>
+</div>
+	
+<div class="box_bottom">
+	<span class="box_bottom_right"></span>
+	<span class="box_bottom_left"></span>
+</div>
 </form>
